pub fn map<K: Clone + Eq + Hash>(results: &[(K, f32)], qrels: &Qrels<K>) -> f32Expand description
Mean Average Precision (MAP).
Average of precision values at each rank where a relevant document appears. MAP is the default metric for MTEB Reranking and TREC evaluations.
Formula: MAP = (1/|R|) * Σ Precision@k * rel(k)
where R is the set of relevant documents and rel(k) is 1 if the document at rank k is relevant.